@@ -1,4 +1,4 @@
-use crate::common::*;
+use super::*;
 
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub(crate) struct Suggestion<'src> {
