@@ -1,8 +1,8 @@
-use crate::common::*;
+use super::*;
 
 #[derive(PartialEq, Debug, Clone)]
 pub(crate) struct UnresolvedDependency<'src> {
-  pub(crate) recipe:    Name<'src>,
+  pub(crate) recipe: Name<'src>,
   pub(crate) arguments: Vec<Expression<'src>>,
 }
 
