@@ -9,8 +9,8 @@ pub(crate) enum Verbosity {
 }
 
 impl Verbosity {
-  pub(crate) fn from_flag_occurrences(flag_occurences: u64) -> Self {
-    match flag_occurences {
+  pub(crate) fn from_flag_occurrences(flag_occurrences: u64) -> Self {
+    match flag_occurrences {
       0 => Taciturn,
       1 => Loquacious,
       _ => Grandiloquent,
