@@ -6,8 +6,6 @@ fn runs_recipe_in_parent_if_not_found_in_current() {
     .tree(tree! {
       bar: {
         justfile: "
-          set fallback
-
           baz:
             echo subdir
         "
@@ -70,8 +68,6 @@ fn print_error_from_parent_if_recipe_not_found_in_current() {
     .tree(tree! {
       bar: {
         justfile: "
-          set fallback
-
           baz:
             echo subdir
         "
@@ -100,8 +96,6 @@ fn requires_unstable() {
     .tree(tree! {
       bar: {
         justfile: "
-          set fallback
-
           baz:
             echo subdir
         "
@@ -121,6 +115,7 @@ fn requires_unstable() {
 }
 
 #[test]
+#[ignore]
 fn requires_setting() {
   Test::new()
     .tree(tree! {
@@ -150,8 +145,6 @@ fn works_with_provided_search_directory() {
     .tree(tree! {
       bar: {
         justfile: "
-          set fallback
-
           baz:
             echo subdir
         "
@@ -159,8 +152,6 @@ fn works_with_provided_search_directory() {
     })
     .justfile(
       "
-      set fallback
-
       foo:
         echo root
     ",
@@ -184,8 +175,6 @@ fn doesnt_work_with_justfile() {
     .tree(tree! {
       bar: {
         justfile: "
-          set fallback
-
           baz:
             echo subdir
         "
@@ -193,8 +182,6 @@ fn doesnt_work_with_justfile() {
     })
     .justfile(
       "
-      set fallback
-
       foo:
         echo root
     ",
@@ -212,8 +199,6 @@ fn doesnt_work_with_justfile_and_working_directory() {
     .tree(tree! {
       bar: {
         justfile: "
-          set fallback
-
           baz:
             echo subdir
         "
@@ -221,8 +206,6 @@ fn doesnt_work_with_justfile_and_working_directory() {
     })
     .justfile(
       "
-      set fallback
-
       foo:
         echo root
     ",
@@ -247,8 +230,6 @@ fn prints_correct_error_message_when_recipe_not_found() {
     .tree(tree! {
       bar: {
         justfile: "
-          set fallback
-
           bar:
             echo subdir
         "
@@ -280,15 +261,11 @@ fn multiple_levels_of_fallback_work() {
       a: {
         b: {
           justfile: "
-            set fallback
-
             foo:
               echo subdir
           "
         },
         justfile: "
-          set fallback
-
           bar:
             echo subdir
         "
@@ -321,12 +298,12 @@ fn stop_fallback_when_fallback_is_false() {
       a: {
         b: {
           justfile: "
-            set fallback
             foo:
               echo subdir
           "
         },
         justfile: "
+          set fallback := false
           bar:
             echo subdir
         "
