@@ -33,6 +33,7 @@ mod test;
 mod allow_duplicate_recipes;
 mod assert_stdout;
 mod assert_success;
+mod attributes;
 mod byte_order_mark;
 mod changelog;
 mod choose;
@@ -60,6 +61,7 @@ mod line_prefixes;
 mod misc;
 mod multibyte_char;
 mod no_exit_message;
+mod os_attributes;
 mod parser;
 mod positional_arguments;
 mod quiet;
